@@ -51,8 +51,8 @@ class CoralSyncClient(CoralClient):
         :type size: int
         :param metadata: Dicionário de metadados do arquivo
         :type metadata: dict, optional
-        :return: Resposta da requisição para o Coral
-        :rtype: requests.Response
+        :return: Objeto do arquivo persistido
+        :rtype: dict
         """
         response = requests.post(
                 '{}/api/sync'.format(self.coral_url),
@@ -66,7 +66,7 @@ class CoralSyncClient(CoralClient):
                 }
             )
         response.raise_for_status()
-        return response
+        return response.json()
 
     def delete_file(self, bucket, key):
         """Remove um arquivo do banco do Coral.
@@ -84,8 +84,8 @@ class CoralSyncClient(CoralClient):
         :type bucket: str
         :param key: Chave do arquivo
         :type key: str
-        :return: Resposta da requisição para o Coral
-        :rtype: requests.Response
+        :return: Código da resposta (204 para successo)
+        :rtype: int
         """
         response = requests.delete(
                 '{}/api/sync'.format(self.coral_url),
@@ -95,4 +95,4 @@ class CoralSyncClient(CoralClient):
                 }
             )
         response.raise_for_status()
-        return response
+        return response.status_code
